#!/usr/bin/python
# -*- coding: utf-8 -*-

########################
#
# Encodage et imports

import sys
import scribus
from calendar import monthrange
from time import localtime

#
########################

if not hasattr(scribus, 'scribus_version_info'):
    raise Exception("This script requires Scribus 1.2.1 or later")

if not scribus.haveDoc():
    scribus.messageBox( "Scribus - Calendrier.py",
            "calendrier.py requires an open document to work.",
            scribus.ICON_INFORMATION)
    sys.exit(1)

########################
#
# Parametrage Modifiable

# On choisi une unité simple
# ici le point typographique
scribus.setUnit(0)

# Nous ne pouvons pas récupérer la taille
# du document. On la fixe donc en dur pour
# le moment
taillePage      = scribus.PAPER_A4

# Nous ne pouvons pas récupérer l'orientation
# du document. On la fixe donc en dur pour
# le moment
# orientationPage = Landscape
orientationPage = scribus.PORTRAIT

# L'année est ici l'année en cours
annee = localtime()[0]

# Largeur de la colonne comportant
# les symboles des jours
largeur_entete = 15

# Hauteur du titre (ici l'année)
hauteur_titre = 40

# Hauteur de la ligne des noms de mois
hauteur_mois = 20

# Hauteur de la marge de haut
marge_h = 35

# Largeur de la marge gauche
marge_v = 35

# Espacement entre les blocs
espacement = 3

# Taille de la police de titre
police_titre = 15

# Taille de la police des mois
police_mois = 9

# Taille de la police par défaut
taille_police_defaut = 7

# Nom de la police par defaut
police_defaut = 'Helmet Normal'

# Symboles des jours
jours = ['L', 'M', 'M', 'J', 'V', 'S', 'D']

# Noms des mois
mois  = [u'Janvier', u'Février', u'Mars', u'Avril', u'Mai', u'Juin', u'Juillet', u'Août', u'Septembre', u'Octobre', u'Novembre', u'Décembre']

scribus.defineColor('ligne_sombre', 10, 64, 25, 0)	# Mauve sombre
scribus.defineColor('ligne_claire', 3, 32, 0, 0)	# Mauve clair
scribus.defineColor('ligne_mois', 58, 22, 0, 0)		# Bleu clair
scribus.defineColor('Fond_Mois', 3, 3, 64, 0)		# Jaune clair
scribus.defineColor('Bord_Mois', 30, 30, 30, 0)		# Gris clair
#
########################

########################
#
# Parametrage interne

if orientationPage == scribus.PORTRAIT:
    l, h = ((taillePage[0] - marge_h * 2 - largeur_entete) / 12, 315)
    l_doc = taillePage[0] - marge_h * 2
    h_doc = taillePage[1] - marge_h * 2
else:
    l, h = ((taillePage[1] - marge_h * 2 - largeur_entete) / 12, 315)
    l_doc = taillePage[1] - marge_h * 2
    h_doc = taillePage[0] - marge_h * 2
#
########################

########################
#
# L'annee en Titre

x, y = (marge_h, marge_v)
a = scribus.createText(marge_h, marge_v, l_doc, hauteur_titre, 'titre')
scribus.insertText(str(annee), 0, a)
scribus.setTextAlignment(1, a)
scribus.setFontSize(police_titre, a)
#
########################

########################
#
# Le Calendrier

# Decor d'arrière plan
hauteur_ligne = 136.1
ecart_ligne = 58.8

for k in range(5):
    num_ligne = k
    nom_ligne = 'ligne' + str(2 * k)

    line_y_start = (hauteur_ligne + num_ligne * ecart_ligne +
                    hauteur_mois + espacement)
    line_y_end   = (hauteur_ligne + num_ligne * ecart_ligne +
                    hauteur_mois + espacement)
    scribus.createLine(
            marge_h,
            line_y_start,
            l_doc + marge_h,
            line_y_end,
            nom_ligne)

    scribus.setLineColor('ligne_sombre', nom_ligne)
    scribus.setLineWidth(1, nom_ligne)

    nom_ligne	= 'ligne' + str(2 * k + 1)
    line_y_start = (hauteur_ligne + num_ligne * ecart_ligne -
                    taille_police_defaut + espacement*2
                    + hauteur_mois)
    line_y_and   = (hauteur_ligne + num_ligne * ecart_ligne -
                    taille_police_defaut + espacement*2 +
                    hauteur_mois)
    scribus.createLine(
            marge_h,
            line_y_start,
            l_doc + marge_h,
            line_y_end,
            nom_ligne)
    scribus.setLineColor('ligne_claire', nom_ligne)
    scribus.setLineWidth(7, nom_ligne)


# Entête des colonnes
# Création de la liste des noms des jours
texte = ''
for j in range(5):
    for i in range(7):
        texte = texte + jours[i] + '\n'

for i in range(2):
    texte = texte + jours[i] + '\n'

# Affichage
x = marge_h
y = marge_v + hauteur_titre + espacement + hauteur_mois + espacement
a = scribus.createText(x, y, largeur_entete, h, 'entete')
scribus.insertText(texte, 0, a)
scribus.setTextAlignment(1, a)
scribus.setFontSize(taille_police_defaut, a)

try:
    scribus.setFont(police_defaut, a)
except (scribus.ScribusException, ValueError):
    scribus.messageBox("Scribus - calendrier.py",
                       "Couldn't find your requested font, %s" % police_defaut
                       +" so the default will be used instead.",
                       scribus.ICON_INFORMATION)

# Jours
# Pour chaque mois
for j in range(12):
    #Nom du mois
    x = marge_h + (l * j) + largeur_entete + espacement
    y = marge_v + hauteur_titre + espacement
    a = scribus.createText(x, y, (l - espacement), hauteur_mois, mois[j])
    scribus.insertText(mois[j], 0, a)
    scribus.setTextAlignment(1, a)
    scribus.setFontSize(police_mois, a)
    scribus.setFillColor('Fond_Mois', a)
    scribus.setLineColor('Bord_Mois', a)
    scribus.setLineJoin(scribus.JOIN_BEVEL , a)

    texte = ''

    # Position du premier jour dans le première semaine
    # en ajoutant autant de ligne vide qu'il faut
    if monthrange(annee, j + 1)[0] != 0:
        for y in range(monthrange(annee, j + 1)[0]):
            texte = texte + ' ' + '\n'

    # Création de la liste des jours
    for y in range(monthrange(annee, j + 1)[1]):
        texte = texte + str(y + 1) + '\n'

    # Affichage des jours
    x = marge_h + (l * j) + largeur_entete + espacement
    y = marge_v + hauteur_titre + espacement + hauteur_mois + espacement
    a = scribus.createText(x, y, (l - espacement), h, 'detail_' + mois[j])
    scribus.insertText(texte, 0, a)
    scribus.setTextAlignment(1, a)
    scribus.setFontSize(taille_police_defaut, a)

    if j != 0:
        # Ligne entre les mois
        name = 'ligne' + mois[j]
        scribus.createLine(
                x - espacement / 2, y,
                x - espacement / 2, y + h,
                name)
        scribus.setLineColor('ligne_mois', name)
        scribus.setFillColor('ligne_mois', name)
        scribus.setLineWidth(1, name)

#
########################
